#include <pdlcore.h>
static Core* PDL; /* Structure holds core C functions */
static SV* CoreSV; /* Gets pointer to perl var holding core structure */
#include <pdlcore.h>
static Core* PDL; /* Structure holds core C functions */
static SV* CoreSV; /* Gets pointer to perl var holding core structure */